<?php
/* $Id: tatarish-iso-8859-9.inc.php,v 1.26 2005/10/30 10:03:50 nijel Exp $ */

$charset = 'iso-8859-9';
$allow_recoding = TRUE;
$text_dir = 'ltr'; // ('ltr' for left to right, 'rtl' for right to left)
$left_font_family = 'verdana, arial, helvetica, geneva, sans-serif';
$right_font_family = 'arial, helvetica, geneva, sans-serif';
$number_thousands_separator = ',';
$number_decimal_separator = '.';
// shortcuts for Byte, Kilo, Mega, Giga, Tera, Peta, Exa
$byteUnits = array('Bayt', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB');

$day_of_week = array('Yk', 'Dm', 'Sm', 'r', 'Pnc', 'Cm', 'mb');
$month = array('n', 'Feb', 'Mar', 'pr', 'May', 'Yn', 'Yl', 'Aug', 'Sen', 'kt', 'Ny', 'Dek');
// See http://www.php.net/manual/en/function.strftime.php to define the
// variable below
$datefmt = '%d.%m.%Y, %H:%M';
$timespanfmt = '%s kn, %s st, %s minut ta %s sekund';

$strAPrimaryKey = '"%s" en tp aq qorld';
$strAbortedClients = 'zderelde';
$strAbsolutePathToDocSqlDir = 'Serverd docSQL trggen kiter yuln kertse';
$strAccessDenied = 'reep Bulmad';
$strAccessDeniedExplanation = 'phpMyAdmin bu MySQL serverg totalp qaraa, server bu totalun zep quyd. Xzer, "config.inc.php" biremend kertelgn sanaqisem/ireisem/serszlr tikserep, alarn MySQL idrese birgn mlmt beln atrp qars qala.';
$strAction = 'ml';
$strAddAutoIncrement = '"AUTO_INCREMENT" bysen stise';
$strAddConstraints = 'iklwlr stise';
$strAddDeleteColumn = 'Add/Delete Field Columns';
$strAddDeleteRow = 'Add/Delete Criteria Row';
$strAddDropDatabase = '"DROP DATABASE" stise';
$strAddFields = '%s alan stw';
$strAddHeaderComment = 'Balqqa stm tawr stw (yullar \\n beln ayrla)';
$strAddIfNotExists = '"IF NOT EXISTS" stise';
$strAddIntoComments = 'Taswrlar een stise';
$strAddNewField = 'Yaa alan stw';
$strAddPrivilegesOnDb = 'Kilse biremleklrg xoquqlar stw';
$strAddPrivilegesOnTbl = 'Kilse table\'lara xoquqlar stw';
$strAddSearchConditions = 'Ezlw artn stw ("WHERE" etlege):';
$strAddToIndex = 'Aqqa tan &nbsp;%s&nbsp;alan stise';
$strAddUser = 'Yaa qullanu stw';
$strAddUserMessage = 'Yana qullanu stlnde.';
$strAddedColumnComment = 'Kilse alana taswr stlende';
$strAddedColumnRelation = 'Kilse alana bylne stlende';
$strAdministration = 'dr';
$strAffectedRows = 'Affected rows:';
$strAfter = '%s artnnan';
$strAfterInsertBack = 'Alda bitk qaytu';
$strAfterInsertNewInsert = 'Tan ber kertem stw';
$strAfterInsertNext = 'Edit next row';
$strAfterInsertSame = 'Bu bitk kire qayt';
$strAll = 'Bars';
$strAllTableSameWidth = 'display all Tables with same width?';
$strAlterOrderBy = 'Table etlegen bolay tez';
$strAnIndex = '"%s" en ber aq qorld';
$strAnalyzeTable = 'Table centeklw';
$strAnd = 'W';
$strAny = 'Hr';
$strAnyHost = 'Bar bulan host';
$strAnyUser = 'Bar bulan qullanu';
$strApproximateCount = 'Trle bula ala. YBS 3.11 qars';
$strArabic = 'rp';
$strArmenian = 'rmn';
$strAscending = 'Artp';
$strAtBeginningOfTable = 'Table Bana';
$strAtEndOfTable = 'Table azana';
$strAttr = 'zenlek';
$strAutodetect = 'Zihenle saylaw';
$strAutomaticLayout = 'Zihenle urnatru';

$strBack = 'Kire';
$strBaltic = 'Baltq';
$strBeginCut = 'BEGIN CUT';
$strBeginRaw = 'BEGIN RAW';
$strBinLogEventType = 'Waqa tre';
$strBinLogInfo = 'Mlmt';
$strBinLogName = 'Log name';
$strBinLogOriginalPosition = 'Trtip buyna urn';
$strBinLogPosition = 'Urn';
$strBinLogServerId = 'Server ID\'e';
$strBinary = 'Binar';
$strBinaryDoNotEdit = 'Binar - zgrtmslek';
$strBinaryLog = 'Binar kndlek';
$strBookmarkAllUsers = 'Bu taman bar qullanua da irele itse';
$strBookmarkDeleted = 'Tama beterelde.';
$strBookmarkLabel = 'Yarlq';
$strBookmarkQuery = 'Tamalanan SQL-soraw';
$strBookmarkThis = 'Bu SQL-sorawa tama quy';
$strBookmarkView = 'Kr gen';
$strBrowse = 'Kzt';
$strBrowseForeignValues = 'Browse foreign values';
$strBufferPool = 'Bufer Pul';
$strBufferPoolActivity = 'Bufer Pul Terelege';
$strBufferPoolUsage = 'Bufer Pul Totlanl';
$strBufferReadMisses = 'Usz uqu';
$strBufferReadMissesInPercent = 'Usz uqu, % en';
$strBufferWriteWaits = 'Yazanda ktter';
$strBufferWriteWaitsInPercent = 'Yazanda ktter, % en';
$strBulgarian = 'Bulgara';
$strBusyPages = 'Et bit';
$strBzError = 'phpMyAdmin was unable to compress the dump because of a broken Bz2 extension in this php version. It is strongly recommended to set the <code>$cfg[\'BZipDump\']</code> directive in your phpMyAdmin configuration file to <code>FALSE</code>. If you want to use the Bz2 compression features, you should upgrade to a later php version. See php bug report %s for details.';
$strBzip = '"bziple"';

$strCSVOptions = 'CSV kylwlre';
$strCalendar = 'Tqwim';
$strCannotLogin = 'MySQL serverg totalp bulmad';
$strCantLoad = '"%s" yklmsen cibrep bulmad,<br />PHP Caylawn tikere';
$strCantLoadRecodeIconv = 'Can not load iconv or recode extension needed for charset conversion, configure php to allow using these extensions or disable charset conversion in phpMyAdmin.';
$strCantRenameIdxToPrimary = 'Aqn "PRIMARY" itep atap bulm!';
$strCantUseRecodeIconv = 'Can not use iconv nor libiconv nor recode_string function while extension reports to be loaded. Check your php configuration.';
$strCardinality = 'Qabatlanu san';
$strCaseInsensitive = 'kee/ol sizmw';
$strCaseSensitive = 'kee/ol siz';
$strCentralEuropean = 'zk Awrup';
$strChange = 'zgrt';
$strChangeCopyMode = 'Create a new user with the same privileges and ...';
$strChangeCopyModeCopy = '... keep the old one.';
$strChangeCopyModeDeleteAndReload = ' ... delete the old one from the user tables and reload the privileges afterwards.';
$strChangeCopyModeJustDelete = ' ... delete the old one from the user tables.';
$strChangeCopyModeRevoke = ' ... revoke all active privileges from the old one and delete it afterwards.';
$strChangeCopyUser = 'Change Login Information / Copy User';
$strChangeDisplay = 'Krstse Alan saylaw';
$strChangePassword = 'Sersz zgrt';
$strCharset = 'Bilgelm';
$strCharsetOfFile = 'ul biremne bilgelmse:';
$strCharsets = 'Bilgelm';
$strCharsetsAndCollations = 'Bilgelm berln Tez trtibe';
$strCheckAll = 'Saylap Beter';
$strCheckOverhead = 'Check overheaded';
$strCheckPrivs = 'Xoquqlar Tiker';
$strCheckPrivsLong = '"%s" biremlege en xoquqlar tiker.';
$strCheckTable = 'Table Tiker';
$strChoosePage = 'Tzt en Bit sayla';
$strColComFeat = 'Baana Taswrlarn Krstse';
$strCollation = 'Tez trtibe';
$strColumnNames = 'Alan iseme';
$strColumnPrivileges = 'Berr baana en xoquqlar';
$strCommand = 'mer';
$strComments = 'Taswrlar';
$strCommentsForTable = 'COMMENTS FOR TABLE';
$strCompatibleHashing = 'MySQL&nbsp;4.0 en yaraql';
$strCompleteInserts = 'Tulaym kert';
$strCompression = 'Qsu';
$strConfigFileError = 'phpMyAdmin was unable to read your configuration file!<br />This might happen if php finds a parse error in it or php cannot find the file.<br />Please call the configuration file directly using the link below and read the php error message(s) that you receive. In most cases a quote or a semicolon is missing somewhere.<br />If you receive a blank page, everything is fine.';
$strConfigureTableCoord = 'Please configure the coordinates for table %s';
$strConnectionError = 'Totaa almm: yaraqsz kylwlr.';
$strConnections = 'Totaular';
$strConstraintsForDumped = 'Constraints for dumped tables';
$strConstraintsForTable = 'Constraints for table';
$strCookiesRequired = 'Cookies must be enabled past this point.';
$strCopyDatabaseOK = 'Database %s has been copied to %s';
$strCopyTable = 'Boa kbyt (biremlek<b>.</b>table):';
$strCopyTableOK = 'Table %s has been copied to %s.';
$strCopyTableSameNames = 'Can\'t copy table to same one!';
$strCouldNotKill = 'phpMyAdmin %s ceben ter almad. Blki ul yablan bulan da inde.';
$strCreate = 'Yasa';
$strCreateIndex = '%s alanna aq qoru';
$strCreateIndexTopic = 'Yaa aq qoru';
$strCreateNewDatabase = 'Yaa biremlek qoru';
$strCreateNewTable = '%s biremlegend yaa table qoru';
$strCreatePage = 'Yaa Bit yasa';
$strCreatePdfFeat = 'PDF\'lar yasaw';
$strCreationDates = 'Yasalu/zgrtel/Tiker zamannar';
$strCriteria = 'art';
$strCroatian = 'Krovata';
$strCyrillic = 'Urslif';
$strCzech = 'ex';
$strCzechSlovak = 'ex-Slovak';

$strDBComment = 'Biremlek taswr:';
$strDBCopy = 'Biremlekne boa kpl';
$strDBGContext = 'Context';
$strDBGContextID = 'Context ID';
$strDBGHits = 'Hit';
$strDBGLine = 'Yul';
$strDBGMaxTimeMs = 'Max waqt, ms';
$strDBGMinTimeMs = 'Min waqt, ms';
$strDBGModule = 'Module';
$strDBGTimePerHitMs = 'Waqt/Hit, ms';
$strDBGTotalTimeMs = 'Tulaym waqt, ms';
$strDBRename = 'Biremlekne bolay ata';
$strDanish = 'Dania';
$strData = 'Etlek';
$strDataDict = 'Etlek Szlege';
$strDataOnly = 'Etlegen gen';
$strDataPages = 'Etlekle bitlr';
$strDatabase = 'Biremlek';
$strDatabaseEmpty = 'Biremlek iseme bu!';
$strDatabaseExportOptions = 'Biremlekne export kylwlre';
$strDatabaseHasBeenDropped = '%s biremlege beterelde.';
$strDatabaseNoTable = 'Bu biremlekt ber gen d table yuq!';
$strDatabases = 'Biremleklr';
$strDatabasesDropped = '"%s" biremlegen beter ul uzd.';
$strDatabasesStats = 'Biremlek nfslre';
$strDatabasesStatsDisable = 'Nfse Snder';
$strDatabasesStatsEnable = 'Nfsne Cibr';
$strDatabasesStatsHeavyTraffic = 'Note: Enabling the Database statistics here might cause heavy traffic between the webserver and the MySQL one.';
$strDbPrivileges = 'Berr biremlekk qall xoquqlar';
$strDbSpecific = 'berr biremlekk qall';
$strDefault = 'dti';
$strDefaultEngine = 'Bu MySQL serverd saqlaw engine bularaq dti itterep %s saylanan.';
$strDefaultValueHelp = 'Gdti by kertknd, kireawtru da, quote een salu da kirk tgel. Bolayraq kertse:: a';
$strDefragment = 'Table kisklren berlter';
$strDelOld = 'The current Page has References to Tables that no longer exist. Would you like to delete those References?';
$strDelayedInserts = 'Ktterep stise';
$strDelete = 'Sal';
$strDeleteAndFlush = 'Beterg, xoquqlarn yaadan yklise.';
$strDeleteAndFlushDescr = 'This is the cleanest way, but reloading the privileges may take a while.';
$strDeleted = 'Bu yazma salnan buld';
$strDeletedRows = 'Salnan yul:';
$strDeleting = '"%s" Beter';
$strDescending = 'Kimep';
$strDescription = 'Taswr';
$strDictionary = 'szlek';
$strDirtyPages = 'zgrtelgn bit';
$strDisableForeignChecks = 'it aqlar tikerne snder';
$strDisabled = 'Snek';
$strDisplayFeat = 'Mmkinleklr Krst';
$strDisplayOrder = 'Krst trtibe:';
$strDisplayPDF = 'PDF schema krst';
$strDoAQuery = '"rnk buyna soraw" ekrt (almatrma: "%")';
$strDoYouReally = 'Sin nlap ta bon elrg teliseme: ';
$strDocu = 'Qullanma';
$strDrop = 'Beter';
$strDropDatabaseStrongWarning = 'You are about to DESTROY a complete database!';
$strDropSelectedDatabases = 'Saylanan Biremlekne Beter';
$strDropUsersDb = 'Biremleklrne ad qullanu adna ti bulsa, beterse alarn.';
$strDumpSaved = 'Etlege "%s" biremen saqland.';
$strDumpXRows = 'Etlek: %s kerem, #%s keremnn balap.';
$strDumpingData = 'Table etlegen aru';
$strDynamic = 'dynamic';

$strEdit = 'Tzt';
$strEditPDFPages = 'PDF Bitlr zgrt';
$strEditPrivileges = 'Xoquqlar zgrt';
$strEffective = 'Nticle';
$strEmpty = 'Buat';
$strEmptyResultSet = 'MySQL sorawa bu cawap, yni nl kertem qaytartt.';
$strEnabled = 'Aq';
$strEncloseInTransaction = 'arun transaks eend tkrerg';
$strEnd = 'Azaq';
$strEndCut = 'END CUT';
$strEndRaw = 'END RAW';
$strEngineAvailable = 'Bu MySQL serverd %s bar.';
$strEngineDisabled = 'Bu MySQL serverd %s snderelgn bulan.';
$strEngineUnsupported = 'Bu MySQL server %s saqlaw enginen totm.';
$strEngines = 'Engine';
$strEnglish = 'ngliz';
$strEnglishPrivileges = ' Bel: MySQL\'da xoquqlar iseme ngliz kertel!';
$strError = 'Xata';
$strEscapeWildcards = 'Wildcards _ and % should be escaped with a \ to use them literally';
$strEstonian = 'Estona';
$strExcelEdition = 'Excel yuramas';
$strExcelOptions = 'Excel kylwlre';
$strExecuteBookmarked = 'Tamalanan soraw cibr';
$strExplain = 'SQL Centeklw';
$strExport = 'Export';
$strExtendedInserts = 'Kiytelgn kert';
$strExtra = 'stm';

$strFailedAttempts = 'Failed attempts';
$strField = 'Alan';
$strFieldHasBeenDropped = '%s isemle alan beterelde';
$strFields = 'Alan';
$strFieldsEmpty = ' Alan klme bu!';
$strFieldsEnclosedBy = 'Alan yabu bilgese';
$strFieldsEscapedBy = 'Alan uzdru bilgese';
$strFieldsTerminatedBy = 'Alan arasnda bilge';
$strFileAlreadyExists = 'File %s already exists on server, change filename or check overwrite option.';
$strFileCouldNotBeRead = 'File could not be read';
$strFileNameTemplate = 'Birem isemene qalb';
$strFileNameTemplateHelp = 'Biremlek adn __DB__ itep, table adn __TABLE__ itep kertse. %sstrftime%s en kylwlr zennn yklner. Baqa mtennr berketelgn.';
$strFileNameTemplateRemember = 'qalpn yatla';
$strFixed = 'berketelgn';
$strFlushPrivilegesNote = 'Bel: phpMyAdmin bu qullanu xoquqlarn MySQL\'n eke table eennn ala. Server qullana toran xoquqlar qul beln zgrtelgn bulsa, bu table etlege alardan ayrla ala. And aqlarda, dawam it aldnnan, %sxoquqlarn yaadan yklrg%s kirk.';
$strFlushTable = 'Table\'n awdar ("FLUSH")';
$strFormEmpty = 'Bu formda by kertelmi qalan!';
$strFormat = 'Qalp';
$strFreePages = 'Bu bit';
$strFullText = 'Tul Mtennr';
$strFunction = 'Funks';

$strGenBy = 'rtke:';
$strGenTime = 'rw Zaman';
$strGeneralRelationFeat = 'Bylnelr buyna tp mmkinleklr';
$strGeorgian = 'Grci';
$strGerman = 'Almana';
$strGlobal = 'mmi';
$strGlobalPrivileges = 'mmi xoquqlar';
$strGlobalValue = 'mmi by';
$strGo = 'yd';
$strGrantOption = 'Xoquq';
$strGreek = 'Yunana';
$strGzip = '"gziple"';

$strHTMLExcel = 'Microsoft Excel 2000';
$strHTMLExcelOptions = 'Microsoft Excel 2000 kebek aru kylwe';
$strHTMLWord = 'Microsoft Word 2000';
$strHTMLWordOptions = 'Microsoft Word 2000 kebek aru kylwe';
$strHasBeenAltered = 'zgrtelde.';
$strHasBeenCreated = 'yasald.';
$strHaveToShow = 'You have to choose at least one Column to display';
$strHebrew = 'Yhd';
$strHexForBinary = 'Binar alan kertknd 16\'l san qullanas';
$strHome = 'Babit';
$strHomepageOfficial = 'phpMyAdmin sxifse';
$strHost = 'Host';
$strHostEmpty = 'Host iseme bu!';
$strHungarian = 'Macara';

$strIcelandic = 'clanda';
$strId = 'ID';
$strIdxFulltext = 'Tulmten';
$strIgnore = 'Qarama';
$strIgnoreInserts = '"IGNORE" beln kertse';
$strIgnoringFile = '"%s" bireme tel';
$strImportDocSQL = 'Import docSQL Files';
$strImportFiles = 'Biremdn alu';
$strImportFinished = 'Import tamam';
$strInUse = 'totla';
$strIndex = 'Aq';
$strIndexHasBeenDropped = '"%s" aq salnd';
$strIndexName = 'Aq iseme&nbsp;:';
$strIndexType = 'Aq tre&nbsp;:';
$strIndexWarningMultiple = '`%s` alanna berdn artq %s aq bar';
$strIndexWarningPrimary = '`%s` alanna PRIMARY da, INDEX da aqlarn berg yasap bulm';
$strIndexWarningTable = '`%s` table aqlar beln nidider qnlqlar bar';
$strIndexWarningUnique = '`%s` alanna UNIQUE da, INDEX da aqlarn berg yasap bulm';
$strIndexes = 'Aqlar';
$strInnoDBAutoextendIncrement = 'Biremlek ollaytu adm';
$strInnoDBAutoextendIncrementDesc = 'Table alan tulan bulanda, an ollaytu adm oll bu.';
$strInnoDBBufferPoolSize = 'Bufer pul oll';
$strInnoDBBufferPoolSizeDesc = 'InnoDB z table en alxter beln aqlar urnatranda bu ollqta bulan bufer qullana.';
$strInnoDBDataFilePath = 'Etlek bireme';
$strInnoDBDataHomeDir = 'Biremnr trgge';
$strInnoDBDataHomeDirDesc = 'InnoDB biremnre en trgk yuln tp lee bu.';
$strInnoDBPages = 'bit';
$strInnodbStat = 'InnoDB Xlte';
$strInsecureMySQL = 'Caylaw biremed, MySQL\'a ire en dti xsap kertelgn (serszsez "root"). MySQL-servere ul dti caylawlar beln alan, and xl iminlikne citdi tiege tip sanala.';
$strInsert = 'stw';
$strInsertAsNewRow = 'Yaa kertem kert t';
$strInsertNewRow = 'Yaa kertem tu';
$strInsertedRowId = 'Kertelgn yazman id:';
$strInsertedRows = 'Kertelgn yazma:';
$strInternalNotNecessary = '* InnoDB eend bulan eke bylnelr qabatlaw kirk tgel.';
$strInternalRelations = 'Eke bylnelr';

$strJapanese = 'Japana';
$strJumpToDB = '&quot;%s&quot; biremlegen k.';
$strJustDelete = 'Xoquqlar table eennn gen beterse.';
$strJustDeleteDescr = 'The &quot;deleted&quot; users will still be able to access the server as usual until the privileges are reloaded.';

$strKeepPass = 'Sersz zgrtse tgel';
$strKeyname = 'Aq iseme';
$strKill = 'ter';
$strKorean = 'Koreya';

$strLaTeX = 'LaTeX';
$strLaTeXOptions = 'LaTeX kylwlre';
$strLandscape = 'Yatqrp';
$strLatchedPages = 'Berketelgn bit';
$strLatexCaption = 'Table bal';
$strLatexContent = '__TABLE__ table etlege';
$strLatexContinued = '(dawaml)';
$strLatexContinuedCaption = 'Table dawamn bal';
$strLatexIncludeCaption = 'Table baln stise';
$strLatexLabel = 'Aq yazmas';
$strLatexStructure = '__TABLE__ table tzelee';
$strLatvian = 'Lata';
$strLengthSet = 'Oznlq/By*';
$strLimitNumRows = 'Bit sayn Kertem san';
$strLinesTerminatedBy = 'Yul ara bilgese';
$strLinkNotFound = 'Bylne tablmad';
$strLinksTo = 'Bon beln bylne:';
$strLithuanian = 'Lithuana';
$strLocalhost = 'Cirle';
$strLocationTextfile = 'Mten biremene urnalu';
$strLogPassword = 'Sersz:';
$strLogServer = 'Server';
$strLogUsername = 'Atama:';
$strLogin = 'Kere';
$strLoginInformation = 'Kere Turnda';
$strLogout = '';
$strLongOperation = 'Bu e ozaqqa suzla ala. Barber eliseme?';

$strMIMETypesForTable = 'MIME TYPES FOR TABLE';
$strMIME_MIMEtype = 'MIME-trlre';
$strMIME_available_mime = 'Barlq MIME-trlr';
$strMIME_available_transform = 'Available transformations';
$strMIME_description = 'Taswr';
$strMIME_nodescription = 'No Description is available for this transformation.<br />Please ask the author, what %s does.';
$strMIME_transformation = 'Browser transformation';
$strMIME_transformation_note = 'For a list of available transformation options and their MIME-type transformations, click on %stransformation descriptions%s';
$strMIME_transformation_options = 'Transformation options';
$strMIME_transformation_options_note = 'Please enter the values for transformation options using this format: \'a\',\'b\',\'c\'...<br />If you ever need to put a backslash ("\") or a single quote ("\'") amongst those values, backslash it (for example \'\\\\xyz\' or \'a\\\'b\').';
$strMIME_without = 'MIME-types printed in italics do not have a seperate transformation function';
$strMaximumSize = 'Max: %s%s';
$strMbExtensionMissing = 'The mbstring PHP extension was not found and you seem to be using multibyte charset. Without mbstring extension phpMyAdmin is unable to split strings correctly and it may result in unexpected results.';
$strMbOverloadWarning = 'You have enabled mbstring.func_overload in your PHP configuration. This option is incompatible with phpMyAdmin and might cause breaking of some data!';
$strModifications = 'zgrtlr saqland';
$strModify = 'zgrt';
$strModifyIndexTopic = 'Aq zgrt';
$strMoveTable = 'Boa ker (biremlek<b>.</b>table):';
$strMoveTableOK = '"%s" atl table "%s" keek atald.';
$strMoveTableSameNames = 'Ber k at beln table kerep bulm!';
$strMultilingual = 'kptelle';
$strMyISAMDataPointerSize = 'Data pointer oll';
$strMyISAMDataPointerSizeDesc = 'MAX_ROWS kylmse bylngn oraqta, CREATE TABLE aa MyISAM table qoranda qullanas pointerne baytl oll.';
$strMyISAMMaxExtraSortFileSize = 'Aq yasaw en waqtl birem olln lw';
$strMyISAMMaxExtraSortFileSizeDesc = 'Bu waqtl birem tiz MyISAM aq qoranda qullanla ikn, ul monda bilgelngn aq alxterennn olraq bulra tie, ul aq alxterlw sulna qarap.';
$strMyISAMMaxSortFileSize = 'Tez en waqtl birem olln lw';
$strMyISAMMaxSortFileSizeDesc = 'MyISAM aqn yaadan qoranda (REPAIR TABLE, ALTER TABLE, y LOAD DATA INFILE aa), MySQL qullanrlq waqtl birem olln iklw bu.';
$strMyISAMRecoverOptions = 'zennn tzl sul';
$strMyISAMRecoverOptionsDesc = 'Cimerelgn MyISAM table zennn tzl sul, serverne --myisam-recover kylmse beln cibrgn aqta kebek.';
$strMyISAMRepairThreads = 'Tzt cebe';
$strMyISAMRepairThreadsDesc = 'Bu by 1dn d olraq ikn, MyISAM table tezle Tzt ee beln berg aqlar qoru ee d cibreler (aq sayn ber ayrm cep).';
$strMyISAMSortBufferSize = 'Tez bufer klme';
$strMyISAMSortBufferSizeDesc = 'REPAIR TABLE aa MyISAM-aq tztknd d, CREATE INDEX y ALTER TABLE aa aq stgnd d yasala toran bufer bu.';
$strMySQLCharset = 'MySQL bilgelmse';
$strMySQLConnectionCollation = 'MySQL il totaun tez trtibe';
$strMySQLReloaded = 'MySQL yaadan cibrelde.';
$strMySQLSaid = 'MySQL cawab:';
$strMySQLServerProcess = 'MySQL-%pma_s1%: %pma_s2% sananda %pma_s3% isemennn eli';
$strMySQLShowProcess = 'Proseslar kr';
$strMySQLShowStatus = 'MySQL ewaqt';
$strMySQLShowVars = 'MySQL zgrmlre';

$strName = 'sem';
$strNext = 'Kilse';
$strNo = 'yuq';
$strNoActivity = 'No activity since %s seconds or more, please login again';
$strNoDatabases = 'Biremleklr yuq';
$strNoDatabasesSelected = 'Biremlek saylanmaan.';
$strNoDescription = 'Taswrlawsz';
$strNoDetailsForEngine = 'Bu saqlaw engine en xlt turnda centekle belem yuq.';
$strNoDropDatabases = '"DROP DATABASE" cnllre snderelgn.';
$strNoExplain = 'SQL Centeklmsk';
$strNoFrames = 'phpMyAdmin is more friendly with a <b>frames-capable</b> browser.';
$strNoIndex = 'Aq bilgelnmde!';
$strNoIndexPartsDefined = 'No index parts defined!';
$strNoModification = 'zgrtsez';
$strNoOptions = 'Bu qalpn kylwlr yuq';
$strNoPassword = 'Serszsez';
$strNoPermission = 'The web server does not have permission to save the file %s.';
$strNoPhp = 'PHP Kodsz';
$strNoPrivileges = 'Xoquqsz';
$strNoRights = 'Bonda bulu en, xoquqlar citmi!';
$strNoRowsSelected = 'Kertemnr saylad';
$strNoSpace = '"%s" biremen saqlaw en bu ara citmi.';
$strNoTablesFound = 'Bu biremlekt ber gen d table yuq.';
$strNoThemeSupport = 'No themes support, please check your configuration and/or your themes in directory %s.';
$strNoUsersFound = 'Qullanu yuq.';
$strNoValidateSQL = 'SQL Tikermsk';
$strNone = 'Yuq';
$strNotNumber = 'San tgel bu!';
$strNotOK = 'OK tgel';
$strNotSet = '<b>%s</b> atl table yuq, y ki "%s" tezmsen kermi';
$strNull = 'Null';
$strNumSearchResultsInTable = '%s kile bar <i>%s</i> table\'da';
$strNumSearchResultsTotal = '<b>Tulaym:</b> <i>%s</i> kile';
$strNumTables = 'Table';

$strOK = 'OK';
$strOperations = 'ml';
$strOperator = 'Operator';
$strOptimizeTable = 'Optimize table';
$strOr = 'Y';
$strOverhead = 'Overhead';
$strOverwriteExisting = 'Birem bar bulsa, stn yazdras';

$strPHP40203 = 'You are using PHP 4.2.3, which has a serious bug with multi-byte strings (mbstring). See PHP bug report 19404. This version of PHP is not recommended for use with phpMyAdmin.';
$strPHPVersion = 'PHP Yuramas';
$strPageNumber = 'Bitne san:';
$strPagesToBeFlushed = 'Buatas bit';
$strPaperSize = 'Qz zuql';
$strPartialText = 'Partial Texts';
$strPassword = 'Sersz';
$strPasswordChanged = '"%s" en sezsz zgrt ul uzd.';
$strPasswordEmpty = 'Sersze bu!';
$strPasswordHashing = 'Sersz Hash\'law';
$strPasswordNotSame = 'Serszlr berbersen kilemi!';
$strPdfDbSchema = '"%s" biremlek tzelee - %s. bit';
$strPdfInvalidTblName = '"%s" atl table yuq le!';
$strPdfNoTables = 'Berr gen d table yuq';
$strPerHour = 'st sayn';
$strPerMinute = 'minut sayn';
$strPerSecond = 'sekund sayn';
$strPersian = 'Farsa';
$strPhoneBook = 'telefon dftre';
$strPhp = 'PHP-Kod yasa';
$strPmaDocumentation = 'phpMyAdmin qullanmas';
$strPmaUriError = 'The <tt>$cfg[\'PmaAbsoluteUri\']</tt> directive MUST be set in your configuration file!';
$strPolish = 'Pola';
$strPortrait = 'Batrp';
$strPos1 = 'Balawa';
$strPrevious = 'Uzan';
$strPrimary = 'Tp';
$strPrimaryKeyHasBeenDropped = 'Tp aq beterelde';
$strPrimaryKeyName = 'Bu tp aqn ad "PRIMARY" bulra tie!';
$strPrimaryKeyWarning = '(Tp aqn <b>na</b> ad "PRIMARY" bulra <b>tie</b>!)';
$strPrint = 'Bastr';
$strPrintView = 'Bastru krenee';
$strPrintViewFull = 'Bastru krenee (bar mtennr beln)';
$strPrivDescAllPrivileges = 'GRANT\'tan basqa bar xoquqlar da bar.';
$strPrivDescAlter = 'Bired bulan table tzeleen zgrt xoquq.';
$strPrivDescAlterRoutine = 'Allows altering and dropping stored routines.';
$strPrivDescCreateDb = 'Yaa biremlek/table yasaw xoquq.';
$strPrivDescCreateRoutine = 'Saqlanan funkslar qorra bir.';
$strPrivDescCreateTbl = 'Yaa table yasaw xoquq.';
$strPrivDescCreateTmpTable = 'Waqtl table yasaw xoquq.';
$strPrivDescCreateUser = 'Qullanu xsabn qoru/salu/ataw een qlra bir.';
$strPrivDescCreateView = 'Yaa qara qorra bir.';
$strPrivDescDelete = 'Etlek beter xoquq.';
$strPrivDescDropDb = 'Biremlek/table beter xoquq.';
$strPrivDescDropTbl = 'Table beter xoquq.';
$strPrivDescExecute = 'Eke prosedur cibr xoquq; MySQL\'n bu yuramasnda yuq le ul.';
$strPrivDescExecute5 = 'Eke funkslar elttererg bir.';
$strPrivDescFile = 'Allows importing data from and exporting data into files.';
$strPrivDescGrant = 'Allows adding users and privileges without reloading the privilege tables.';
$strPrivDescIndex = 'Aqlarn qoru/beter xoquq.';
$strPrivDescInsert = 'Etlek stw/almatru xoquq.';
$strPrivDescLockTables = 'Allows locking tables for the current thread.';
$strPrivDescMaxConnections = 'Limits the number of new connections the user may open per hour.';
$strPrivDescMaxQuestions = 'Limits the number of queries the user may send to the server per hour.';
$strPrivDescMaxUpdates = 'Limits the number of commands that change any table or database the user may execute per hour.';
$strPrivDescProcess3 = 'Allows killing processes of other users.';
$strPrivDescProcess4 = 'Allows viewing the complete queries in the process list.';
$strPrivDescReferences = 'Has no effect in this MySQL version.';
$strPrivDescReload = 'Allows reloading server settings and flushing the server\'s caches.';
$strPrivDescReplClient = 'Gives the right to the user to ask where the slaves / masters are.';
$strPrivDescReplSlave = 'Needed for the replication slaves.';
$strPrivDescSelect = 'Etlekne uqu xoquq.';
$strPrivDescShowDb = 'Gives access to the complete list of databases.';
$strPrivDescShowView = 'SHOW CREATE VIEW sorawlarn elterlek it.';
$strPrivDescShutdown = 'Serverne tuqtatu xoquq.';
$strPrivDescSuper = 'Allows connecting, even if maximum number of connections is reached; Required for most administrative operations like setting global variables or killing threads of other users.';
$strPrivDescUpdate = 'Etlek zgrt xoquq.';
$strPrivDescUsage = 'Xoquqlar yuq.';
$strPrivileges = 'Xoquqlar';
$strPrivilegesReloaded = 'Bu xoquqlarn yklw ul uzd.';
$strProcesslist = 'Proses isemlege';
$strPutColNames = 'Berene yulda alannarn iseme aras';

$strQBE = 'Soraw';
$strQBEDel = 'Sal';
$strQBEIns = 'Tq';
$strQueryFrame = 'Soraw trzse';
$strQueryOnDb = '<b>%s</b> biremlegen SQL-soraw:';
$strQuerySQLHistory = 'SQL-tarx';
$strQueryStatistics = '<b>Soraw nfse</b>: Bu serverne yklndn so, aa %s soraw birelgn bulan.';
$strQueryTime = 'Soraw ekrt %01.4f sek ald';
$strQueryType = 'Soraw tre';
$strQueryWindowLock = 'Bu sorawn, trz tnda bulan beln almatras tgel';

$strReType = 'Qabatla';
$strReadRequests = 'Uqua soraw';
$strReceived = 'Caytarnd';
$strRecords = 'Yazma';
$strReferentialIntegrity = 'Bylnelrne dreslekk tiker:';
$strRefresh = 'Yaart';
$strRelationNotWorking = 'Bylnekn Table beln elw en, stm mmkinleklr snek tora. An qabzu en, %sbonda trt%s.';
$strRelationView = 'Bylnelr qaraw';
$strRelationalSchema = 'Bylnelr sxeme';
$strRelations = 'Bylnelr';
$strRelationsForTable = 'RELATIONS FOR TABLE';
$strReloadFailed = 'MySQL ykln almad.';
$strReloadMySQL = 'MySQL\'n yaadan cibr';
$strReloadingThePrivileges = 'Bu xoquqlarn ykl';
$strRemoveSelectedUsers = 'Saylanan qullanu beter';
$strRenameDatabaseOK = '"%s" biremlegen "%s" at quld';
$strRenameTable = 'Table ismen zgrt';
$strRenameTableOK = '"%s" table\'na "%s" at quld';
$strRepairTable = 'Table tzet';
$strReplaceNULLBy = 'NULL\'n almatras:';
$strReplaceTable = 'Table etlegen bu biremlektge beln alamtras';
$strReset = 'Awdar';
$strResourceLimits = 'Resurs iklwlre';
$strRevoke = 'Ter';
$strRevokeAndDelete = 'Bu qullanularn xoquqlarn awdarp beterse.';
$strRevokeAndDeleteDescr = 'The users will still have the USAGE privilege until the privileges are reloaded.';
$strRevokeMessage = 'You have revoked the privileges for %s';
$strRomanian = 'Romana';
$strRowLength = 'Kertem oznl';
$strRowSize = ' Kerem zurl';
$strRows = 'Kerem';
$strRowsFrom = 'kerem, twgese #';
$strRowsModeFlippedHorizontal = 'horizontal (balqlar almap)';
$strRowsModeHorizontal = 'horizontal';
$strRowsModeOptions = '%s sul beln; balqn %s yul sayn qabatls';
$strRowsModeVertical = 'vertical';
$strRowsStatistic = 'Kerem Nfse';
$strRunQuery = 'Yulla Saylawn';
$strRunSQLQuery = 'SQL-sorawn %s biremlegend ekrt';
$strRunning = 'Sanaq: %s';
$strRussian = 'Ursa';

$strSQL = 'SQL';
$strSQLExportCompatibility = 'SQL yuramasn yaraqlatru';
$strSQLExportType = 'aru sul';
$strSQLOptions = 'SQL kylwlre';
$strSQLParserBugMessage = 'There is a chance that you may have found a bug in the SQL parser. Please examine your query closely, and check that the quotes are correct and not mis-matched. Other possible failure causes may be that you are uploading a file with binary outside of a quoted text area. You can also try your query on the MySQL command line interface. The MySQL server error output below, if there is any, may also help you in diagnosing the problem. If you still have problems or if the parser fails where the command line interface succeeds, please reduce your SQL query input to the single query that causes problems, and submit a bug report with the data chunk in the CUT section below:';
$strSQLParserUserError = 'There seems to be an error in your SQL query. The MySQL server error output below, if there is any, may also help you in diagnosing the problem';
$strSQLQuery = 'SQL-soraw';
$strSQLResult = 'SQL nticse';
$strSQPBugInvalidIdentifer = 'Invalid Identifer';
$strSQPBugUnclosedQuote = 'Yablmaan quote';
$strSQPBugUnknownPunctuation = 'Unknown Punctuation String';
$strSave = 'Saqla';
$strSaveOnServer = 'Serverne "%s" trggend saqla';
$strScaleFactorSmall = 'Bu sxemn ber bitt urnatru en, ollq san bik kee';
$strSearch = 'Ezlw';
$strSearchFormTitle = 'Ezlw, biremlekt: ';
$strSearchInTables = 'Bu table eend:';
$strSearchNeedle = 'Kilsen ezlw en sz/bylr (almatrma: "%"):';
$strSearchOption1 = 'bu szlrne berrse bulsa';
$strSearchOption2 = 'bar szlrne';
$strSearchOption3 = 'sztezmne tgl';
$strSearchOption4 = 'regexp kebek';
$strSearchResultsFor = '"<i>%s</i>" ezlw nticse %s:';
$strSearchType = 'Ezl:';
$strSecretRequired = 'The configuration file now needs a secret passphrase (blowfish_secret).';
$strSelectADb = 'Berr biremlek sayls';
$strSelectAll = 'Saylap Beter';
$strSelectBinaryLog = 'Qaraw en binar kndlek saylaw';
$strSelectFields = 'Alannar sayls (i kimend ber):';
$strSelectNumRows = 'sorawda';
$strSelectTables = 'Table Sayla';
$strSend = 'Biremg saqla';
$strSent = 'Cibrelde';
$strServer = 'Server';
$strServerChoice = 'Server Saylaw';
$strServerNotResponding = 'Bu server endmi';
$strServerStatus = 'Eor Turnda';
$strServerStatusUptime = 'Bu MySQL-server %s eli. Ul %s zamannda cibrelgn bulan.';
$strServerTabProcesslist = 'Proseslar';
$strServerTabVariables = 'zgrmlr';
$strServerTrafficNotes = '<b>Server tam</b>: Bonda table eend, MySQL serverene cibreldn so, ul server beln eltr arasnda bulan tam turnda belem birel.';
$strServerVars = 'Serverne zgrm/kylwlre';
$strServerVersion = 'Server yuramas';
$strSessionValue = 'Sessi byse';
$strSetEnumVal = 'Alan tre "enum/set" bulsa, bysen bu qalpta kertse: \'a\',\'b\',\'c\'...<br />By een kireaw ("\") y sarquote ("\'") kertse bulsa, an kireawtras bula (rnk: \'\\\\xyz\' y ki \'a\\\'b\').';
$strShow = 'Krst';
$strShowAll = 'Barsn krst';
$strShowColor = 'Show color';
$strShowDatadictAs = 'Etlek Szlegene Format';
$strShowFullQueries = 'Tul Sorawlar Krst';
$strShowGrid = 'Show grid';
$strShowPHPInfo = 'PHP turnda';
$strShowTableDimension = 'Show dimension of tables';
$strShowTables = 'Show tables';
$strShowThisQuery = ' Bu sorawn bonda tan krstse';
$strShowingRecords = 'Kertem:';
$strSimplifiedChinese = 'Ciel in';
$strSingly = '(sar)';
$strSize = 'Zurlq';
$strSlovak = 'Slovaka';
$strSlovenian = 'Slovena';
$strSocketProblem = '(y bu cirle MySQL server soket dres kylnmgn ide)';
$strSort = 'Tez';
$strSortByKey = 'Sort by key';
$strSpaceUsage = 'Ara qullanu';
$strSpanish = 'Spanish';
$strSplitWordsWithSpace = 'Szlr bulq bilgese beln ayrlan (" ").';
$strStatCheckTime = 'So tiker';
$strStatCreateTime = 'Yasalu';
$strStatUpdateTime = 'So yaartlu';
$strStatement = 'Cml';
$strStatus = 'Status';
$strStorageEngine = 'Saqlaw Engine';
$strStorageEngines = 'Saqlaw Engine';
$strStrucCSV = 'CSV bireme';
$strStrucData = 'Tzeleen d, etlegen d';
$strStrucDrop = '"DROP TABLE" stise';
$strStrucExcelCSV = 'CSV bireme, MS Excel en';
$strStrucNativeExcel = 'MS Excel\'n z format';
$strStrucOnly = 'Tzeleen gen';
$strStructPropose = 'Table tzeleen kzt';
$strStructure = 'Tzele';
$strSubmit = 'Yulla';
$strSuccess = 'SQL-soraw ul ekrtelde';
$strSum = 'Sum';
$strSwedish = 'swc';
$strSwitchToDatabase = 'Kplngn biremlekk kse';
$strSwitchToTable = 'Kplngn table\'a kse';

$strTable = 'table';
$strTableComments = 'Table tfsire';
$strTableEmpty = 'Table ad kertelmi qald!';
$strTableHasBeenDropped = '"%s" atl table beterelde';
$strTableHasBeenEmptied = '"%s" atl table buatld';
$strTableHasBeenFlushed = '"%s" atl table awdarld';
$strTableMaintenance = 'Table ekrt';
$strTableOfContents = 'Etlek isemlege';
$strTableOptions = 'Table kylwe';
$strTableStructure = 'Table tzelee';
$strTableType = 'Table tre';
$strTables = '%s table';
$strTakeIt = 'bon sayla';
$strTblPrivileges = 'Berr table en xoquqlar';
$strTextAreaLength = ' Because of its length,<br /> this field might not be editable';
$strThai = 'Taya';
$strTheme = 'Tlaw / Bizle';
$strThisHost = 'Bu Sanaq';
$strThisNotDirectory = 'Trgk tgel ul';
$strThreadSuccessfullyKilled = '%s cebe ul terelgn buld.';
$strTime = 'Waqt';
$strToggleScratchboard = 'Toggle scratchboard';
$strTotal = 'tulaym';
$strTotalUC = 'Tulaym';
$strTraditionalChinese = 'dti in';
$strTraditionalSpanish = 'dti spana';
$strTraffic = 'Tam';
$strTransformation_application_octetstream__download = 'Display a link to download the binary data of a field. First option is the filename of the binary file. Second option is a possible fieldname of a table row containing the filename. If you provide a second option you need to have the first option set to an empty string';
$strTransformation_image_jpeg__inline = 'Displays a clickable thumbnail; options: width,height in pixels (keeps the original ratio)';
$strTransformation_image_jpeg__link = 'Displays a link to this image (direct blob download, i.e.).';
$strTransformation_image_png__inline = 'See image/jpeg: inline';
$strTransformation_text_plain__dateformat = 'Takes a TIME, TIMESTAMP or DATETIME field and formats it using your local dateformat. First option is the offset (in hours) which will be added to the timestamp (Default: 0). Second option is a different dateformat according to the parameters available for PHPs strftime().';
$strTransformation_text_plain__external = 'LINUX IA: Launches an external application and feeds the fielddata via standard input. Returns standard output of the application. Default is Tidy, to pretty print HTML code. For security reasons, you have to manually edit the file libraries/transformations/text_plain__external.inc.php and insert the tools you allow to be run. The first option is then the number of the program you want to use and the second option are the parameters for the program. The third parameter, if set to 1 will convert the output using htmlspecialchars() (Default is 1). A fourth parameter, if set to 1 will put a NOWRAP to the content cell so that the whole output will be shown without reformatting (Default 1)';
$strTransformation_text_plain__formatted = 'Preserves original formatting of the field. No Escaping is done.';
$strTransformation_text_plain__imagelink = 'Displays an image and a link, the field contains the filename; first option is a prefix like "http://domain.com/", second option is the width in pixels, third is the height.';
$strTransformation_text_plain__link = 'Displays a link, the field contains the filename; first option is a prefix like "http://domain.com/", second option is a title for the link.';
$strTransformation_text_plain__substr = 'Only shows part of a string. First option is an offset to define where the output of your text starts (Default 0). Second option is an offset how much text is returned. If empty, returns all the remaining text. The third option defines which chars will be appended to the output when a substring is returned (Default: ...) .';
$strTruncateQueries = 'Sorawn Qsqartp Krstse';
$strTurkish = 'Trek';
$strType = 'Tre';

$strUkrainian = 'Ukraina';
$strUncheckAll = 'Saylanun Beter';
$strUnicode = 'Unicode';
$strUnique = 'Qabatsz';
$strUnknown = 'belgesez';
$strUnselectAll = 'Saylanun Ter';
$strUpdComTab = 'Sine Column_comments Table yaartu ee turnda Qullanmada qars';
$strUpdatePrivMessage = 'You have updated the privileges for %s.';
$strUpdateProfileMessage = 'The profile has been updated.';
$strUpdateQuery = 'Sorawn Yaart';
$strUpgrade = 'You should upgrade to %s %s or later.';
$strUsage = 'Totlu';
$strUseBackquotes = 'Table/alan isemnren kirequote een salas';
$strUseHostTable = 'Host Table eennn';
$strUseTabKey = 'Ber bydn ikeneg k en TAB tymsen qullanas, baqa cirg k en, CTRL+uq tymlre bar';
$strUseTables = 'Use Tables';
$strUseTextField = 'Bu mtennn';
$strUseThisValue = 'Bu by beln';
$strUser = 'Qullanu';
$strUserAlreadyExists = '"%s" atl qullanu bar inde!';
$strUserEmpty = 'Atama bu!';
$strUserName = 're iseme';
$strUserNotFound = 'Bu qullanu xoquqlar table eend tablmad.';
$strUserOverview = 'Qullanular isemlege';
$strUsersDeleted = 'Saylanan qullanun beter ul uzan.';
$strUsersHavingAccessToDb = '"%s" beln elw xoquq bulan qullanular';

$strValidateSQL = 'SQL\'n Tiker';
$strValidatorError = 'SQL-tikere kylnmgn. Bu kirk bulan php-yklmne kylw turnda %squllanmada%s uqp bula.';
$strValue = 'By';
$strVar = 'zgrelm';
$strVersionInformation = 'Yurama turnda';
$strView = 'Qara';
$strViewDump = 'Table etlegen (tzeleen) aru';
$strViewDumpDB = 'Biremlek etlegen (tzeleen) aru';
$strViewDumpDatabases = 'Biremleklrne etlegen (tzeleen) aru';
$strViewHasBeenDropped = '"%s" atl Qara beterelgn buld';

$strWebServerUploadDirectory = 'web-server\'ne yklw trgge';
$strWebServerUploadDirectoryError = 'Yklw en bigelngn trgkne uqp bulm';
$strWelcome = 'Rxim it yt: %s';
$strWestEuropean = 'Bat Awrup';
$strWildcard = 'wildcard';
$strWindowNotFound = 'Browsern maqsat trzse yaartlm qald. Ana-trz yablan bulan blki, y browsern iminlek caylawnda, trz-ara yaartua tlu bar.';
$strWithChecked = 'Saylanann:';
$strWriteRequests = 'Yazua soraw';
$strWritingCommentNotPossible = 'Taswr stw mmkin tgel';
$strWritingRelationNotPossible = 'Bylne kert mmkin tgel';
$strWrongUser = 'Atama/sersze yal. reep Bulmad.';

$strXML = 'XML';

$strYes = 'ye';

$strZeroRemovesTheLimit = 'Bel: Monda 0 (Nl) kertels, iklw betereler.';
$strZip = '"ziple"';

// To translate:

$strCreateDatabaseBeforeCopying = 'CREATE DATABASE before copying';  //to translate

$strGeneratePassword = 'Generate Password';  //to translate
$strGenerate = 'Generate';  //to translate
$strCopy = 'Copy';  //to translate
$strTransformation_application_octetstream__hex = 'Displays hexadecimal representation of data.';  //to translate
$strInvalidFieldCount = 'Table must have at least one field.';  //to translate
$strInvalidRowNumber = '%d is not valid row number.';  //to translate
$strInvalidColumnCount = 'Column count has to be larger than zero.';  //to translate
$strInvalidFieldAddCount = 'You have to add at least one field.';  //to translate
$strAndThen = 'and then';  //to translate
$strInvalidAuthMethod = 'Invalid authentication method set in configuration:';  //to translate
$strRunSQLQueryOnServer = 'Run SQL query/queries on server %s';  //to translate
$strCSV = 'CSV';  //to translate
$strImport = 'Import';  //to translate
$strImportFormat = 'Format of imported file';  //to translate
$strFileToImport = 'File to import';  //to translate
$strCompressionWillBeDetected = 'Imported file compression will be automatically detected from: %s';  //to translate
$strCanNotLoadImportPlugins = 'Could not load import plugins, please check your installation!';  //to translate
$strEnclosingOptional = 'Enclosing of fields is optional';  //to translate
$strCSVImportOptions = 'CSV options';  //to translate
$strPartialImport = 'Partial import';  //to translate
$strAllowInterrupt = 'Allow interrupt of import in case script detects it is close to time limit. This might be good way to import large files, however it can break transactions.';  //to translate
$strTimeoutPassed = 'Script timeout passed, if you want to finish import, please resubmit same file and import will resume.';  //to translate
$strTimeoutNothingParsed = 'However on last run no data has been parsed, this usually means phpMyAdmin won\'t be able to finish this import unless you increase php time limits.';  //to translate
$strTimeoutInfo = 'Previous import timed out, after resubmitting will continue from position %d.';  //to translate
$strUnsupportedCompressionDetected = 'You attempted to load file with unsupported compression (%s). Either support for it is not implemented or disabled by your configuration.';  //to translate
$strNothingToImport = 'You didn\'t enter any data to import!';  //to translate
$strIgnoreDuplicates = 'Ignore duplicate rows';  //to translate
$strSkipQueries = 'Number of records(queries) to skip from start';  //to translate
$strInvalidColumn = 'Invalid column (%s) specified!';  //to translate
$strInvalidCSVInput = 'Invalid CSV input, could not parse!';  //to translate
$strNoFilesFoundInZip = 'No files found inside ZIP archive!';  //to translate
$strErrorInZipFile = 'Error in ZIP archive:';  //to translate
$strFlushQueryCache = 'Flush query cache';  //to translate
$strFlushTables = 'Flush (close) all tables';  //to translate
$strHandler = 'Handler';  //to translate
$strJoins = 'Joins';  //to translate
$strKeyCache = 'Key cache';  //to translate
$strMaxConnects = 'max. concurrent connections';  //to translate
$strQueryCache = 'Query cache';  //to translate
$strReplication = 'Replication';  //to translate
$strServerStatusDelayedInserts = 'Delayed inserts';  //to translate
$strShowOpenTables = 'Show open tables';  //to translate
$strShowSlaveHosts = 'Show slave hosts';  //to translate
$strShowSlaveStatus = 'Show slave status';  //to translate
$strShowStatusReset = 'Reset';  //to translate
$strShowStatusBinlog_cache_disk_useDescr = 'The number of transactions that used the temporary binary log cache but that exceeded the value of binlog_cache_size and used a temporary file to store statements from the transaction.';  //to translate
$strShowStatusBinlog_cache_useDescr = 'The number of transactions that used the temporary binary log cache.';  //to translate
$strShowStatusCreated_tmp_disk_tablesDescr = 'The number of temporary tables on disk created automatically by the server while executing statements. If Created_tmp_disk_tables is big, you may want to increase the tmp_table_size  value to cause temporary tables to be memory-based instead of disk-based.';  //to translate
$strShowStatusCreated_tmp_filesDescr = 'How many temporary files mysqld has created.';  //to translate
$strShowStatusCreated_tmp_tablesDescr = 'The number of in-memory temporary tables created automatically by the server while executing statements.';  //to translate
$strShowStatusDelayed_errorsDescr = 'The number of rows written with INSERT DELAYED for which some error occurred (probably duplicate key).';  //to translate
$strShowStatusDelayed_insert_threadsDescr = 'The number of INSERT DELAYED handler threads in use. Every different table on which one uses INSERT DELAYED gets its own thread.';  //to translate
$strShowStatusDelayed_writesDescr = 'The number of INSERT DELAYED rows written.';  //to translate
$strShowStatusFlush_commandsDescr  = 'The number of executed FLUSH statements.';  //to translate
$strShowStatusHandler_commitDescr = 'The number of internal COMMIT statements.';  //to translate
$strShowStatusHandler_deleteDescr = 'The number of times a row was deleted from a table.';  //to translate
$strShowStatusHandler_discoverDescr = 'The MySQL server can ask the NDB Cluster storage engine if it knows about a table with a given name. This is called discovery. Handler_discover indicates the number of time tables have been discovered.';  //to translate
$strShowStatusHandler_read_firstDescr = 'The number of times the first entry was read from an index. If this is high, it suggests that the server is doing a lot of full index scans; for example, SELECT col1 FROM foo, assuming that col1 is indexed.';  //to translate
$strShowStatusHandler_read_keyDescr = 'The number of requests to read a row based on a key. If this is high, it is a good indication that your queries and tables are properly indexed.';  //to translate
$strShowStatusHandler_read_nextDescr = 'The number of requests to read the next row in key order. This is incremented if you are querying an index column with a range constraint or if you are doing an index scan.';  //to translate
$strShowStatusHandler_read_prevDescr = 'The number of requests to read the previous row in key order. This read method is mainly used to optimize ORDER BY ... DESC.';  //to translate
$strShowStatusHandler_read_rndDescr = 'The number of requests to read a row based on a fixed position. This is high if you are doing a lot of queries that require sorting of the result. You probably have a lot of queries that require MySQL to scan whole tables or you have joins that don\'t use keys properly.';  //to translate
$strShowStatusHandler_read_rnd_nextDescr = 'The number of requests to read the next row in the data file. This is high if you are doing a lot of table scans. Generally this suggests that your tables are not properly indexed or that your queries are not written to take advantage of the indexes you have.';  //to translate
$strShowStatusHandler_rollbackDescr = 'The number of internal ROLLBACK statements.';  //to translate
$strShowStatusHandler_updateDescr = 'The number of requests to update a row in a table.';  //to translate
$strShowStatusHandler_writeDescr = 'The number of requests to insert a row in a table.';  //to translate
$strShowStatusInnodb_buffer_pool_pages_dataDescr = 'The number of pages containing data (dirty or clean).';  //to translate
$strShowStatusInnodb_buffer_pool_pages_dirtyDescr = 'The number of pages currently dirty.';  //to translate
$strShowStatusInnodb_buffer_pool_pages_flushedDescr = 'The number of buffer pool pages that have been requested to be flushed.';  //to translate
$strShowStatusInnodb_buffer_pool_pages_freeDescr = 'The number of free pages.';  //to translate
$strShowStatusInnodb_buffer_pool_pages_latchedDescr = 'The number of latched pages in InnoDB buffer pool. These are pages currently being read or written or that can\'t be flushed or removed for some other reason.';  //to translate
$strShowStatusInnodb_buffer_pool_pages_miscDescr = 'The number of pages busy because they have been allocated for administrative overhead such as row locks or the adaptive hash index. This value can also be calculated as Innodb_buffer_pool_pages_total - Innodb_buffer_pool_pages_free - Innodb_buffer_pool_pages_data.';  //to translate
$strShowStatusInnodb_buffer_pool_pages_totalDescr = 'Total size of buffer pool, in pages.';  //to translate
$strShowStatusInnodb_buffer_pool_read_ahead_rndDescr = 'The number of "random" read-aheads InnoDB initiated. This happens when a query is to scan a large portion of a table but in random order.';  //to translate
$strShowStatusInnodb_buffer_pool_read_ahead_seqDescr = 'The number of sequential read-aheads InnoDB initiated. This happens when InnoDB does a sequential full table scan.';  //to translate
$strShowStatusInnodb_buffer_pool_read_requestsDescr = 'The number of logical read requests InnoDB has done.';  //to translate
$strShowStatusInnodb_buffer_pool_readsDescr = 'The number of logical reads that InnoDB could not satisfy from buffer pool and had to do a single-page read.';  //to translate
$strShowStatusInnodb_buffer_pool_wait_freeDescr = 'Normally, writes to the InnoDB buffer pool happen in the background. However, if it\'s necessary to read or create a page and no clean pages are available, it\'s necessary to wait for pages to be flushed first. This counter counts instances of these waits. If the buffer pool size was set properly, this value should be small.';  //to translate
$strShowStatusInnodb_buffer_pool_write_requestsDescr = 'The number writes done to the InnoDB buffer pool.';  //to translate
$strShowStatusInnodb_data_fsyncsDescr = 'The number of fsync() operations so far.';  //to translate
$strShowStatusInnodb_data_pending_fsyncsDescr = 'The current number of pending fsync() operations.';  //to translate
$strShowStatusInnodb_data_pending_readsDescr = 'The current number of pending reads.';  //to translate
$strShowStatusInnodb_data_pending_writesDescr = 'The current number of pending writes.';  //to translate
$strShowStatusInnodb_data_readDescr = 'The amount of data read so far, in bytes.';  //to translate
$strShowStatusInnodb_data_readsDescr = 'The total number of data reads.';  //to translate
$strShowStatusInnodb_data_writesDescr = 'The total number of data writes.';  //to translate
$strShowStatusInnodb_data_writtenDescr = 'The amount of data written so far, in bytes.';  //to translate
$strShowStatusInnodb_dblwr_pages_writtenDescr = 'The number of doublewrite writes that have been performed and the number of pages that have been written for this purpose.';  //to translate
$strShowStatusInnodb_dblwr_writesDescr = 'The number of doublewrite writes that have been performed and the number of pages that have been written for this purpose.';  //to translate
$strShowStatusInnodb_log_waitsDescr = 'The number of waits we had because log buffer was too small and we had to wait for it to be flushed before continuing.';  //to translate
$strShowStatusInnodb_log_write_requestsDescr = 'The number of log write requests.';  //to translate
$strShowStatusInnodb_log_writesDescr = 'The number of physical writes to the log file.';  //to translate
$strShowStatusInnodb_os_log_fsyncsDescr = 'The number of fsyncs writes done to the log file.';  //to translate
$strShowStatusInnodb_os_log_pending_fsyncsDescr = 'The number of pending log file fsyncs.';  //to translate
$strShowStatusInnodb_os_log_pending_writesDescr = 'Pending log file writes.';  //to translate
$strShowStatusInnodb_os_log_writtenDescr = 'The number of bytes written to the log file.';  //to translate
$strShowStatusInnodb_page_sizeDescr = 'The compiled-in InnoDB page size (default 16KB). Many values are counted in pages; the page size allows them to be easily converted to bytes.';  //to translate
$strShowStatusInnodb_pages_createdDescr = 'The number of pages created.';  //to translate
$strShowStatusInnodb_pages_readDescr = 'The number of pages read.';  //to translate
$strShowStatusInnodb_pages_writtenDescr = 'The number of pages written.';  //to translate
$strShowStatusInnodb_row_lock_current_waitsDescr = 'The number of row locks currently being waited for.';  //to translate
$strShowStatusInnodb_row_lock_timeDescr = 'The total time spent in acquiring row locks, in milliseconds.';  //to translate
$strShowStatusInnodb_row_lock_time_avgDescr = 'The average time to acquire a row lock, in milliseconds.';  //to translate
$strShowStatusInnodb_row_lock_time_maxDescr = 'The maximum time to acquire a row lock, in milliseconds.';  //to translate
$strShowStatusInnodb_row_lock_waitsDescr = 'The number of times a row lock had to be waited for.';  //to translate
$strShowStatusInnodb_rows_deletedDescr = 'The number of rows deleted from InnoDB tables.';  //to translate
$strShowStatusInnodb_rows_insertedDescr = 'The number of rows inserted in InnoDB tables.';  //to translate
$strShowStatusInnodb_rows_readDescr = 'The number of rows read from InnoDB tables.';  //to translate
$strShowStatusInnodb_rows_updatedDescr = 'The number of rows updated in InnoDB tables.';  //to translate
$strShowStatusKey_blocks_not_flushedDescr = 'The number of key blocks in the key cache that have changed but haven\'t yet been flushed to disk. It used to be known as Not_flushed_key_blocks.';  //to translate
$strShowStatusKey_blocks_unusedDescr = 'The number of unused blocks in the key cache. You can use this value to determine how much of the key cache is in use.';  //to translate
$strShowStatusKey_blocks_usedDescr = 'The number of used blocks in the key cache. This value is a high-water mark that indicates the maximum number of blocks that have ever been in use at one time.';  //to translate
$strShowStatusKey_read_requestsDescr = 'The number of requests to read a key block from the cache.';  //to translate
$strShowStatusKey_readsDescr = 'The number of physical reads of a key block from disk. If Key_reads is big, then your key_buffer_size value is probably too small. The cache miss rate can be calculated as Key_reads/Key_read_requests.';  //to translate
$strShowStatusKey_write_requestsDescr = 'The number of requests to write a key block to the cache.';  //to translate
$strShowStatusKey_writesDescr = 'The number of physical writes of a key block to disk.';  //to translate
$strShowStatusLast_query_costDescr = 'The total cost of the last compiled query as computed by the query optimizer. Useful for comparing the cost of different query plans for the same query. The default value of 0 means that no query has been compiled yet.';  //to translate
$strShowStatusNot_flushed_delayed_rowsDescr = 'The number of rows waiting to be written in INSERT DELAY queues.';  //to translate
$strShowStatusOpen_filesDescr = 'The number of files that are open.';  //to translate
$strShowStatusOpen_streamsDescr = 'The number of streams that are open (used mainly for logging).';  //to translate
$strShowStatusOpen_tablesDescr = 'The number of tables that are open.';  //to translate
$strShowStatusOpened_tablesDescr = 'The number of tables that have been opened. If opened tables is big, your table cache value is probably too small.';  //to translate
$strShowStatusQcache_free_blocksDescr = 'The number of free memory blocks in query cache.';  //to translate
$strShowStatusQcache_free_memoryDescr = 'The amount of free memory for query cache.';  //to translate
$strShowStatusQcache_hitsDescr = 'The number of cache hits.';  //to translate
$strShowStatusQcache_insertsDescr = 'The number of queries added to the cache.';  //to translate
$strShowStatusQcache_lowmem_prunesDescr = 'The number of queries that have been removed from the cache to free up memory for caching new queries. This information can help you tune the query cache size. The query cache uses a least recently used (LRU) strategy to decide which queries to remove from the cache.';  //to translate
$strShowStatusQcache_not_cachedDescr = 'The number of non-cached queries (not cachable, or not cached due to the query_cache_type setting).';  //to translate
$strShowStatusQcache_queries_in_cacheDescr = 'The number of queries registered in the cache.';  //to translate
$strShowStatusQcache_total_blocksDescr = 'The total number of blocks in the query cache.';  //to translate
$strShowStatusRpl_statusDescr = 'The status of failsafe replication (not yet implemented).';  //to translate
$strShowStatusSelect_full_joinDescr = 'The number of joins that do not use indexes. If this value is not 0, you should carefully check the indexes of your tables.';  //to translate
$strShowStatusSelect_full_range_joinDescr = 'The number of joins that used a range search on a reference table.';  //to translate
$strShowStatusSelect_rangeDescr = 'The number of joins that used ranges on the first table. (It\'s normally not critical even if this is big.)';  //to translate
$strShowStatusSelect_range_checkDescr = 'The number of joins without keys that check for key usage after each row. (If this is not 0, you should carefully check the indexes of your tables.)';  //to translate
$strShowStatusSelect_scanDescr = 'The number of joins that did a full scan of the first table.';  //to translate
$strShowStatusSlave_open_temp_tablesDescr = 'The number of temporary tables currently open by the slave SQL thread.';  //to translate
$strShowStatusSlave_retried_transactionsDescr = 'Total (since startup) number of times the replication slave SQL thread has retried transactions.';  //to translate
$strShowStatusSlave_runningDescr = 'This is ON if this server is a slave that is connected to a master.';  //to translate
$strShowStatusSlow_launch_threadsDescr = 'The number of threads that have taken more than slow_launch_time seconds to create.';  //to translate
$strShowStatusSlow_queriesDescr = 'The number of queries that have taken more than long_query_time seconds.';  //to translate
$strShowStatusSort_merge_passesDescr = 'The number of merge passes the sort algorithm has had to do. If this value is large, you should consider increasing the value of the sort_buffer_size system variable.';  //to translate
$strShowStatusSort_rangeDescr = 'The number of sorts that were done with ranges.';  //to translate
$strShowStatusSort_rowsDescr = 'The number of sorted rows.';  //to translate
$strShowStatusSort_scanDescr = 'The number of sorts that were done by scanning the table.';  //to translate
$strShowStatusTable_locks_immediateDescr = 'The number of times that a table lock was acquired immediately.';  //to translate
$strShowStatusTable_locks_waitedDescr = 'The number of times that a table lock could not be acquired immediately and a wait was needed. If this is high, and you have performance problems, you should first optimize your queries, and then either split your table or tables or use replication.';  //to translate
$strShowStatusThreads_cachedDescr = 'The number of threads in the thread cache. The cache hit rate can be calculated as Threads_created/Connections. If this value is red you should raise your thread_cache_size.';  //to translate
$strShowStatusThreads_connectedDescr = 'The number of currently open connections.';  //to translate
$strShowStatusThreads_createdDescr = 'The number of threads created to handle connections. If Threads_created is big, you may want to increase the thread_cache_size value. (Normally this doesn\'t give a notable performance improvement if you have a good thread implementation.)';  //to translate
$strShowStatusThreads_runningDescr = 'The number of threads that are not sleeping.';  //to translate
$strSorting = 'Sorting';  //to translate
$strTempData = 'Temporary data';  //to translate
$strThreads = 'Threads';  //to translate
$strLDI = 'CSV using LOAD DATA';  //to translate
$strLDILocal = 'Use LOCAL keyword';  //to translate
$strLDIImportOptions = 'Options for CSV import using LOAD DATA';  //to translate
$strInvalidLDIImport = 'This plugin does not support compressed imports!';  //to translate
$strTableAlreadyExists = 'Table %s already exists!';  //to translate
$strTransactionCoordinator = 'Transaction coordinator';  //to translate
$strNumberOfFields = 'Number of fields';  //to translate
$strShowingBookmark = 'Showing bookmark';  //to translate
$strUploadLimit = 'You probably tried to upload too large file. Please refer to %sdocumentation%s for ways to workaround this limit.';  //to translate
$strDeleteNoUsersSelected = 'No users selected for deleting!';  //to translate
$strPrivDescMaxUserConnections = 'Limits the number of simultaneous connections the user may have.';  //to translate
$strMaximalQueryLength = 'Maximal length of created query';  //to translate
$strBookmarkCreated = 'Bookmark %s created';  //to translate
$strBookmarkReplace = 'Replace existing bookmark of same name';  //to translate
$strTransformation_text_plain__sql = 'Formats text as SQL query with syntax highlighting.';  //to translate
$strEsperanto = 'Esperanto';  //to translate
?>
